@@ -9,8 +9,6 @@
 #include "codecompletiontestmodels.h"
 // #include "codecompletiontestmodels.moc"
 
-#include <ksycoca.h>
-
 #include <ktexteditor/document.h>
 #include <ktexteditor/editor.h>
 
@@ -22,12 +20,14 @@
 #include <katerenderer.h>
 #include <kateview.h>
 
+#include <QApplication>
 #include <QKeyEvent>
-#include <QtTestWidgets>
+#include <QTest>
 
 QTEST_MAIN(CompletionTest)
 
 using namespace KTextEditor;
+static constexpr int TIMEOUT = 2000;
 
 int countItems(KateCompletionModel *model)
 {
@@ -44,12 +44,12 @@ int countItems(KateCompletionModel *model)
 
 static void verifyCompletionStarted(KTextEditor::ViewPrivate *view)
 {
-    QTRY_VERIFY_WITH_TIMEOUT(view->completionWidget()->isCompletionActive(), 1000);
+    QTRY_VERIFY_WITH_TIMEOUT(view->completionWidget()->isCompletionActive(), TIMEOUT);
 }
 
 static void verifyCompletionAborted(KTextEditor::ViewPrivate *view)
 {
-    QTRY_VERIFY_WITH_TIMEOUT(!view->completionWidget()->isCompletionActive(), 1000);
+    QTRY_VERIFY_WITH_TIMEOUT(!view->completionWidget()->isCompletionActive(), TIMEOUT);
 }
 
 static void invokeCompletionBox(KTextEditor::ViewPrivate *view)
@@ -93,8 +93,7 @@ void CompletionTest::testFilterEmptyRange()
 
     QCOMPARE(countItems(model), 40);
     m_view->insertText(QStringLiteral("aa"));
-    QTest::qWait(1000); // process events
-    QCOMPARE(countItems(model), 14);
+    QTRY_COMPARE_WITH_TIMEOUT(countItems(model), 14, TIMEOUT);
 }
 
 void CompletionTest::testFilterWithRange()
@@ -110,8 +109,7 @@ void CompletionTest::testFilterWithRange()
     QCOMPARE(countItems(model), 14);
 
     m_view->insertText(QStringLiteral("a"));
-    QTest::qWait(1000); // process events
-    QCOMPARE(countItems(model), 1);
+    QTRY_COMPARE_WITH_TIMEOUT(countItems(model), 1, TIMEOUT);
 }
 
 void CompletionTest::testAbortCursorMovedOutOfRange()
@@ -126,8 +124,7 @@ void CompletionTest::testAbortCursorMovedOutOfRange()
     QVERIFY(m_view->completionWidget()->isCompletionActive());
 
     m_view->setCursorPosition(Cursor(0, 4));
-    QTest::qWait(1000); // process events
-    QVERIFY(!m_view->completionWidget()->isCompletionActive());
+    verifyCompletionAborted(m_view);
 }
 
 void CompletionTest::testAbortInvalidText()
@@ -160,8 +157,7 @@ void CompletionTest::testCustomRange1()
     QCOMPARE(countItems(model), 14);
 
     m_view->insertText(QStringLiteral("a"));
-    QTest::qWait(1000); // process events
-    QCOMPARE(countItems(model), 1);
+    QTRY_COMPARE_WITH_TIMEOUT(countItems(model), 1, TIMEOUT);
 }
 
 void CompletionTest::testCustomRange2()
@@ -178,8 +174,7 @@ void CompletionTest::testCustomRange2()
     QCOMPARE(countItems(model), 40);
 
     m_view->insertText(QStringLiteral("aa"));
-    QTest::qWait(1000); // process events
-    QCOMPARE(countItems(model), 14);
+    QTRY_COMPARE_WITH_TIMEOUT(countItems(model), 14, TIMEOUT);
 }
 
 void CompletionTest::testCustomRangeMultipleModels()
@@ -199,8 +194,7 @@ void CompletionTest::testCustomRangeMultipleModels()
     QCOMPARE(countItems(model), 80);
 
     m_view->insertText(QStringLiteral("aa"));
-    QTest::qWait(1000); // process events
-    QCOMPARE(model->currentCompletion(testModel1), QStringLiteral("$aa"));
+    QTRY_COMPARE_WITH_TIMEOUT(model->currentCompletion(testModel1), QStringLiteral("$aa"), TIMEOUT);
     QCOMPARE(model->currentCompletion(testModel2), QStringLiteral("aa"));
     QCOMPARE(countItems(model), 14 * 2);
 }
@@ -217,8 +211,7 @@ void CompletionTest::testAbortController()
     QVERIFY(m_view->completionWidget()->isCompletionActive());
 
     m_view->insertText(QStringLiteral("$a"));
-    QTest::qWait(1000); // process events
-    QVERIFY(m_view->completionWidget()->isCompletionActive());
+    verifyCompletionStarted(m_view);
 
     m_view->insertText(QStringLiteral("."));
     verifyCompletionAborted(m_view);
@@ -237,21 +230,18 @@ void CompletionTest::testAbortControllerMultipleModels()
     QVERIFY(m_view->completionWidget()->isCompletionActive());
 
     m_view->insertText(QStringLiteral("a"));
-    QTest::qWait(1000); // process events
-    QVERIFY(m_view->completionWidget()->isCompletionActive());
+    verifyCompletionStarted(m_view);
     QCOMPARE(countItems(model), 80);
 
     m_view->insertText(QStringLiteral("-"));
-    QTest::qWait(1000); // process events
-    QVERIFY(m_view->completionWidget()->isCompletionActive());
+    verifyCompletionStarted(m_view);
     QVERIFY(!m_view->completionWidget()->completionRanges().contains(testModel1));
     QVERIFY(m_view->completionWidget()->completionRanges().contains(testModel2));
 
     QCOMPARE(countItems(model), 40);
 
     m_view->insertText(QLatin1String(" "));
-    QTest::qWait(1000); // process events
-    QVERIFY(!m_view->completionWidget()->isCompletionActive());
+    verifyCompletionAborted(m_view);
 }
 
 void CompletionTest::testEmptyFilterString()
@@ -265,12 +255,10 @@ void CompletionTest::testEmptyFilterString()
     QCOMPARE(countItems(model), 40);
 
     m_view->insertText(QStringLiteral("a"));
-    QTest::qWait(1000); // process events
-    QCOMPARE(countItems(model), 40);
+    QTRY_COMPARE_WITH_TIMEOUT(countItems(model), 40, TIMEOUT);
 
     m_view->insertText(QStringLiteral("bam"));
-    QTest::qWait(1000); // process events
-    QCOMPARE(countItems(model), 40);
+    QTRY_COMPARE_WITH_TIMEOUT(countItems(model), 40, TIMEOUT);
 }
 
 void CompletionTest::testUpdateCompletionRange()
@@ -286,13 +274,16 @@ void CompletionTest::testUpdateCompletionRange()
     QCOMPARE(Range(*m_view->completionWidget()->completionRange(testModel)), Range(Cursor(0, 3), Cursor(0, 3)));
 
     m_view->insertText(QStringLiteral("ab"));
-    QTest::qWait(1000); // process events
-    QCOMPARE(Range(*m_view->completionWidget()->completionRange(testModel)), Range(Cursor(0, 0), Cursor(0, 5)));
-    QCOMPARE(countItems(model), 40);
+    QTRY_COMPARE_WITH_TIMEOUT(Range(*m_view->completionWidget()->completionRange(testModel)), Range(Cursor(0, 0), Cursor(0, 5)), TIMEOUT);
+    QTRY_COMPARE_WITH_TIMEOUT(countItems(model), 40, TIMEOUT);
 }
 
 void CompletionTest::testCustomStartCompl()
 {
+#ifdef __SANITIZE_ADDRESS__
+    QSKIP("issues with Qt 6.5 and sanitizer");
+#endif
+
     KateCompletionModel *model = m_view->completionWidget()->model();
 
     m_view->completionWidget()->setAutomaticInvocationDelay(1);
@@ -300,10 +291,9 @@ void CompletionTest::testCustomStartCompl()
     new StartCompletionModel(m_view, QStringLiteral("aa"));
 
     m_view->setCursorPosition(Cursor(0, 0));
-    m_view->insertText("%");
-    QTest::qWait(1000);
+    m_view->insertText(QStringLiteral("%"));
 
-    QVERIFY(m_view->completionWidget()->isCompletionActive());
+    verifyCompletionStarted(m_view);
     QCOMPARE(countItems(model), 40);
 }
 
@@ -391,7 +381,7 @@ void CompletionTest::testAutoCompletionPreselectFirst()
     m_view->config()->setValue(KateViewConfig::AutomaticCompletionPreselectFirst, false);
     // When AutomaticCompletionPreselectFirst is disabled, immediately pressing enter
     // should result into a newline instead of completion
-    m_doc->setText("a");
+    m_doc->setText(QStringLiteral("a"));
     m_view->setCursorPosition(Cursor(0, 1));
     m_view->completionWidget()->automaticInvocation();
     verifyCompletionStarted(m_view);
@@ -399,7 +389,7 @@ void CompletionTest::testAutoCompletionPreselectFirst()
     QApplication::sendEvent(m_view->focusProxy(), &enterKeyEvent);
 
     verifyCompletionAborted(m_view);
-    QCOMPARE(m_doc->text(), "a\n");
+    QCOMPARE(m_doc->text(), QStringLiteral("a\n"));
 }
 
 void CompletionTest::testTabCompletion()
@@ -412,46 +402,46 @@ void CompletionTest::testTabCompletion()
     m_view->config()->setValue(KateViewConfig::AutomaticCompletionPreselectFirst, true);
 
     // Nothing to do, already selected
-    m_doc->setText("a");
+    m_doc->setText(QStringLiteral("a"));
     m_view->completionWidget()->automaticInvocation();
     QVERIFY(m_view->completionWidget()->isCompletionActive());
     m_view->completionWidget()->execute();
     QVERIFY(!m_view->completionWidget()->isCompletionActive());
-    QCOMPARE(m_doc->text(), "aaa0");
+    QCOMPARE(m_doc->text(), QStringLiteral("aaa0"));
 
     // First entry already selected, going down will select the next completion
-    m_doc->setText("a");
+    m_doc->setText(QStringLiteral("a"));
     m_view->completionWidget()->automaticInvocation();
     QVERIFY(m_view->completionWidget()->isCompletionActive());
     m_view->completionWidget()->tabCompletion(KateCompletionWidget::Down);
     m_view->completionWidget()->execute();
     QVERIFY(!m_view->completionWidget()->isCompletionActive());
-    QCOMPARE(m_doc->text(), "aad3");
+    QCOMPARE(m_doc->text(), QStringLiteral("aad3"));
 
     // First entry _not_ already selected...
     m_view->config()->setValue(KateViewConfig::AutomaticCompletionPreselectFirst, false);
 
-    m_doc->setText("a");
+    m_doc->setText(QStringLiteral("a"));
     m_view->completionWidget()->automaticInvocation();
     QVERIFY(m_view->completionWidget()->isCompletionActive());
     // ... Tab will select the first entry
     m_view->completionWidget()->tabCompletion(KateCompletionWidget::Down);
     m_view->completionWidget()->execute();
     QVERIFY(!m_view->completionWidget()->isCompletionActive());
-    QCOMPARE(m_doc->text(), "aaa0");
+    QCOMPARE(m_doc->text(), QStringLiteral("aaa0"));
 
     // While at the top, going up, cycles to the bottom of the list
-    m_doc->setText("a");
+    m_doc->setText(QStringLiteral("a"));
     m_view->completionWidget()->automaticInvocation();
     QVERIFY(m_view->completionWidget()->isCompletionActive());
     m_view->completionWidget()->cursorDown(); // Select first entry
     m_view->completionWidget()->tabCompletion(KateCompletionWidget::Up);
     m_view->completionWidget()->execute();
     QVERIFY(!m_view->completionWidget()->isCompletionActive());
-    QCOMPARE(m_doc->text(), "ac\u008738");
+    QCOMPARE(m_doc->text(), QStringLiteral("ac\u008738"));
 
     // While at the bottom, going down cycles to the top of the list
-    m_doc->setText("a");
+    m_doc->setText(QStringLiteral("a"));
     m_view->completionWidget()->automaticInvocation();
     QVERIFY(m_view->completionWidget()->isCompletionActive());
     m_view->completionWidget()->cursorDown(); // Select first entry
@@ -460,7 +450,7 @@ void CompletionTest::testTabCompletion()
     m_view->completionWidget()->tabCompletion(KateCompletionWidget::Down);
     m_view->completionWidget()->execute();
     QVERIFY(!m_view->completionWidget()->isCompletionActive());
-    QCOMPARE(m_doc->text(), "aaa0");
+    QCOMPARE(m_doc->text(), QStringLiteral("aaa0"));
 }
 
 void CompletionTest::benchAbbreviationEngineGoodCase()
@@ -509,7 +499,7 @@ void CompletionTest::testAbbrevAndContainsMatching()
 
     m_view->document()->setText(QStringLiteral("SC"));
     invokeCompletionBox(m_view);
-    QCOMPARE(model->filteredItemCount(), (uint)9);
+    QCOMPARE(model->filteredItemCount(), (uint)6);
 
     m_view->document()->setText(QStringLiteral("sca"));
     invokeCompletionBox(m_view);
@@ -517,20 +507,20 @@ void CompletionTest::testAbbrevAndContainsMatching()
 
     m_view->document()->setText(QStringLiteral("contains"));
     invokeCompletionBox(m_view);
-    QCOMPARE(model->filteredItemCount(), (uint)3);
+    QCOMPARE(model->filteredItemCount(), (uint)2);
 
     m_view->document()->setText(QStringLiteral("CONTAINS"));
     invokeCompletionBox(m_view);
-    QCOMPARE(model->filteredItemCount(), (uint)3);
+    QCOMPARE(model->filteredItemCount(), (uint)2);
 
     m_view->document()->setText(QStringLiteral("containssome"));
     invokeCompletionBox(m_view);
-    QCOMPARE(model->filteredItemCount(), (uint)2);
+    QCOMPARE(model->filteredItemCount(), (uint)1);
 
     m_view->document()->setText(QStringLiteral("matched"));
     m_view->userInvokedCompletion();
     QApplication::processEvents();
-    QCOMPARE(model->filteredItemCount(), (uint)1);
+    QCOMPARE(model->filteredItemCount(), (uint)0);
 }
 
 void CompletionTest::testAsyncMatching()
@@ -550,7 +540,7 @@ void CompletionTest::testAsyncMatching()
 void CompletionTest::benchCompletionModel()
 {
     const int testFactor = 1;
-    const QString text("abcdefg abcdef");
+    const QString text(QStringLiteral("abcdefg abcdef"));
     m_doc->setText(text);
     CodeCompletionTestModel *testModel1 = new CodeCompletionTestModel(m_view, QStringLiteral("abcdefg"));
     testModel1->setRowCount(50 * testFactor);
