@@ -1,20 +1,8 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2011-2018 Dominik Haumann <dhaumann@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2011-2018 Dominik Haumann <dhaumann@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "modificationsystem_test.h"
@@ -24,7 +12,7 @@
 #include <kateglobal.h>
 #include <kateundomanager.h>
 
-#include <QtTestWidgets>
+#include <QTest>
 
 QTEST_MAIN(ModificationSystemTest)
 
@@ -62,7 +50,7 @@ void ModificationSystemTest::testInsertText()
 {
     KTextEditor::DocumentPrivate doc;
 
-    const QString content("first line\n");
+    const QString content(QStringLiteral("first line\n"));
     doc.setText(content);
 
     // now all lines should have state "Modified"
@@ -79,7 +67,7 @@ void ModificationSystemTest::testInsertText()
 
     // now we have an a unmodified file, start real tests
     // insert text in line 0, then undo and redo
-    doc.insertText(Cursor(0, 2), "_");
+    doc.insertText(Cursor(0, 2), QStringLiteral("_"));
     QVERIFY(doc.isLineModified(0));
     QVERIFY(!doc.isLineSaved(0));
 
@@ -116,7 +104,7 @@ void ModificationSystemTest::testRemoveText()
 {
     KTextEditor::DocumentPrivate doc;
 
-    const QString content("first line\n");
+    const QString content(QStringLiteral("first line\n"));
     doc.setText(content);
 
     // now all lines should have state "Modified"
@@ -171,8 +159,8 @@ void ModificationSystemTest::testInsertLine()
     KTextEditor::DocumentPrivate doc;
 
     const QString content(
-        "0\n"
-        "2");
+        QStringLiteral("0\n"
+                       "2"));
     doc.setText(content);
 
     // clear all modification flags, forces no flags
@@ -181,7 +169,7 @@ void ModificationSystemTest::testInsertLine()
     clearModificationFlags(&doc);
 
     // insert at line 1
-    doc.insertLine(1, "1");
+    doc.insertLine(1, QStringLiteral("1"));
 
     QVERIFY(!doc.isLineModified(0));
     QVERIFY(doc.isLineModified(1));
@@ -240,9 +228,9 @@ void ModificationSystemTest::testRemoveLine()
     KTextEditor::DocumentPrivate doc;
 
     const QString content(
-        "0\n"
-        "1\n"
-        "2");
+        QStringLiteral("0\n"
+                       "1\n"
+                       "2"));
     doc.setText(content);
 
     // clear all modification flags, forces no flags
@@ -308,9 +296,9 @@ void ModificationSystemTest::testWrapLineMid()
         KTextEditor::DocumentPrivate doc;
 
         const QString content(
-            "aaaa\n"
-            "bbbb\n"
-            "cccc");
+            QStringLiteral("aaaa\n"
+                           "bbbb\n"
+                           "cccc"));
         doc.setText(content);
 
         // clear all modification flags, forces no flags
@@ -379,8 +367,8 @@ void ModificationSystemTest::testWrapLineAtEnd()
     KTextEditor::DocumentPrivate doc;
 
     const QString content(
-        "aaaa\n"
-        "bbbb");
+        QStringLiteral("aaaa\n"
+                       "bbbb"));
     doc.setText(content);
 
     // clear all modification flags, forces no flags
@@ -448,8 +436,8 @@ void ModificationSystemTest::testWrapLineAtStart()
     KTextEditor::DocumentPrivate doc;
 
     const QString content(
-        "aaaa\n"
-        "bbbb");
+        QStringLiteral("aaaa\n"
+                       "bbbb"));
     doc.setText(content);
 
     // clear all modification flags, forces no flags
@@ -517,9 +505,9 @@ void ModificationSystemTest::testUnWrapLine()
     KTextEditor::DocumentPrivate doc;
 
     const QString content(
-        "aaaa\n"
-        "bbbb\n"
-        "cccc");
+        QStringLiteral("aaaa\n"
+                       "bbbb\n"
+                       "cccc"));
     doc.setText(content);
 
     // clear all modification flags, forces no flags
@@ -583,9 +571,9 @@ void ModificationSystemTest::testUnWrapLine1Empty()
     KTextEditor::DocumentPrivate doc;
 
     const QString content(
-        "aaaa\n"
-        "\n"
-        "bbbb");
+        QStringLiteral("aaaa\n"
+                       "\n"
+                       "bbbb"));
     doc.setText(content);
 
     // clear all modification flags, forces no flags
@@ -649,9 +637,9 @@ void ModificationSystemTest::testUnWrapLine2Empty()
     KTextEditor::DocumentPrivate doc;
 
     const QString content(
-        "aaaa\n"
-        "\n"
-        "bbbb");
+        QStringLiteral("aaaa\n"
+                       "\n"
+                       "bbbb"));
     doc.setText(content);
 
     // clear all modification flags, forces no flags
@@ -715,9 +703,9 @@ void ModificationSystemTest::testNavigation()
     KTextEditor::DocumentPrivate doc;
 
     const QString content(
-        "0\n"
-        "1\n"
-        "2");
+        QStringLiteral("0\n"
+                       "1\n"
+                       "2"));
     doc.setText(content);
 
     // clear all modification flags, forces no flags
@@ -726,8 +714,8 @@ void ModificationSystemTest::testNavigation()
     clearModificationFlags(&doc);
 
     // touch line 0 and line 2:
-    doc.insertText(Cursor(0, 1), QLatin1String("-"));
-    doc.insertText(Cursor(2, 1), QLatin1String("-"));
+    doc.insertText(Cursor(0, 1), QStringLiteral("-"));
+    doc.insertText(Cursor(2, 1), QStringLiteral("-"));
 
     // test down navigation:
     const bool down = true;
