@@ -7,12 +7,11 @@
 #ifndef KATE_TEXTBLOCK_H
 #define KATE_TEXTBLOCK_H
 
-#include <unordered_map>
-#include <unordered_set>
+#include "katetextline.h"
 
+#include <QList>
 #include <QSet>
 #include <QVarLengthArray>
-#include <QVector>
 
 #include <ktexteditor/cursor.h>
 #include <ktexteditor_export.h>
@@ -28,14 +27,14 @@ class TextBuffer;
 class TextCursor;
 class TextRange;
 class TextLineData;
-typedef QSharedPointer<TextLineData> TextLine;
+typedef std::shared_ptr<TextLineData> TextLine;
 
 /**
  * Class representing a text block.
  * This is used to build up a Kate::TextBuffer.
  * This class should only be used by TextBuffer/Cursor/Range.
  */
-class KTEXTEDITOR_EXPORT TextBlock
+class TextBlock
 {
 public:
     /**
@@ -72,6 +71,17 @@ public:
      */
     TextLine line(int line) const;
 
+    /**
+     * Retrieve length for @p line.
+     * @param line wanted line number
+     * @return length of line
+     */
+    int lineLength(int line) const
+    {
+        Q_ASSERT(line >= startLine() && (line - startLine()) < lines());
+        return m_lines[line - startLine()]->length();
+    }
+
     /**
      * Append a new line with given text.
      * @param textOfLine text of the line to append
@@ -103,7 +113,7 @@ public:
      * @param position line/column as cursor where to wrap
      * @param fixStartLinesStartIndex start index to fix start lines, normally this is this block
      */
-    void wrapLine(const KTextEditor::Cursor &position, int fixStartLinesStartIndex);
+    void wrapLine(const KTextEditor::Cursor position, int fixStartLinesStartIndex);
 
     /**
      * Unwrap given line.
@@ -118,14 +128,14 @@ public:
      * @param position position where to insert text
      * @param text text to insert
      */
-    void insertText(const KTextEditor::Cursor &position, const QString &text);
+    void insertText(const KTextEditor::Cursor position, const QString &text);
 
     /**
      * Remove text at given range.
      * @param range range of text to remove, must be on one line only.
      * @param removedText will be filled with removed text
      */
-    void removeText(const KTextEditor::Range &range, QString &removedText);
+    void removeText(KTextEditor::Range range, QString &removedText);
 
     /**
      * Debug output, print whole block content with line numbers and line length
@@ -168,7 +178,9 @@ public:
      * @param rangesWithAttributeOnly       ranges with attributes only?
      * @return list of possible candidate ranges
      */
-    QVector<TextRange *> rangesForLine(int line, KTextEditor::View *view, bool rangesWithAttributeOnly) const;
+    KTEXTEDITOR_EXPORT QList<TextRange *> rangesForLine(int line, KTextEditor::View *view, bool rangesWithAttributeOnly) const;
+
+    KTEXTEDITOR_NO_EXPORT void rangesForLine(int line, KTextEditor::View *view, bool rangesWithAttributeOnly, QList<TextRange *> &outRanges) const;
 
     /**
      * Is the given range contained in this block?
@@ -200,7 +212,7 @@ public:
      */
     void removeCursor(Kate::TextCursor *cursor)
     {
-        m_cursors.erase(cursor);
+        m_cursors.remove(cursor);
     }
 
     /**
@@ -216,19 +228,29 @@ public:
      */
     void removeRange(TextRange *range);
 
+    /**
+     * Returns the size of this block i.e.,
+     * the count of QChars it has + number of new lines
+     */
+    int blockSize() const
+    {
+        return m_blockSize + m_lines.size();
+    }
+
+private:
     /**
      * Return all ranges in this block which might intersect the given line and only span one line.
      * For them an internal fast lookup cache is hold.
      * @param line line to check intersection
      * @return set of ranges
      */
-    QSet<TextRange *> cachedRangesForLine(int line) const
+    const QVarLengthArray<TextRange *, 6> *cachedRangesForLine(int line) const
     {
         line -= m_startLine;
         if (line >= 0 && (size_t)line < m_cachedRangesForLine.size()) {
-            return m_cachedRangesForLine[line];
+            return &m_cachedRangesForLine[line];
         } else {
-            return QSet<TextRange *>();
+            return nullptr;
         }
     }
 
@@ -250,21 +272,26 @@ private:
     int m_startLine;
 
     /**
-     * Set of cursors for this block.
-     * We need no sharing, use STL.
+     * size of block i.e., number of QChars
      */
-    std::unordered_set<TextCursor *> m_cursors;
+    int m_blockSize = 0;
+
+    /**
+     * Set of cursors for this block.
+     * using QSet is better than unordered_set for perf reasons
+     */
+    QSet<TextCursor *> m_cursors;
 
     /**
      * Contains for each line-offset the ranges that were cached into it.
      * These ranges are fully contained by the line.
      */
-    std::vector<QSet<TextRange *>> m_cachedRangesForLine;
+    std::vector<QVarLengthArray<TextRange *, 6>> m_cachedRangesForLine;
 
     /**
      * Maps for each cached range the line into which the range was cached.
      */
-    std::unordered_map<TextRange *, int> m_cachedLineForRanges;
+    QHash<TextRange *, int> m_cachedLineForRanges;
 
     /**
      * This contains all the ranges that are not cached.
