@@ -1,30 +1,18 @@
-/*  SPDX-License-Identifier: LGPL-2.0-or-later
+/*
+    SPDX-FileCopyrightText: 2014 Christoph Rüßler <christoph.ruessler@mailbox.org>
 
-    Copyright (C) 2014 Christoph Rüßler <christoph.ruessler@mailbox.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "katehighlightingcmds.h"
 
+#include <ktexteditor/application.h>
+#include <ktexteditor/editor.h>
+#include <ktexteditor/view.h>
+
 #include "katedocument.h"
-#include "kateglobal.h"
 #include "katehighlight.h"
 #include "katesyntaxmanager.h"
-#include "kateview.h"
 
 #include <QUrl>
 
@@ -33,9 +21,7 @@ KateCommands::Highlighting *KateCommands::Highlighting::m_instance = nullptr;
 bool KateCommands::Highlighting::exec(KTextEditor::View *view, const QString &cmd, QString &, const KTextEditor::Range &)
 {
     if (cmd.startsWith(QLatin1String("reload-highlighting"))) {
-        KateHlManager *manager = KTextEditor::EditorPrivate::self()->hlManager();
-        manager->reload();
-
+        KateHlManager::self()->reload();
         return true;
     } else if (cmd.startsWith(QLatin1String("edit-highlighting"))) {
         KTextEditor::DocumentPrivate *document = static_cast<KTextEditor::DocumentPrivate *>(view->document());
