@@ -13,20 +13,18 @@
 
 #include "kateautoindent.h"
 
+#include "attribute.h"
 #include "katedocument.h"
-#include "kateextendedattribute.h"
 #include "kateglobal.h"
 #include "katehighlight.h"
 #include "kateindentscript.h"
 #include "katepartdebug.h"
 #include "katescriptmanager.h"
-#include "kateview.h"
 
 #include <KLocalizedString>
 
 #include <QActionGroup>
-
-#include <cctype>
+#include <QMenu>
 
 namespace
 {
