@@ -16,6 +16,7 @@
 
 #include <KConfigGroup>
 
+#include <KEncodingProber>
 #include <QGuiApplication>
 #include <QSettings>
 #include <QStringDecoder>
@@ -825,7 +826,7 @@ void KateRendererConfig::reloadSchema()
     if (isGlobal()) {
         setSchemaInternal(m_schema);
         for (KTextEditor::ViewPrivate *view : KTextEditor::EditorPrivate::self()->views()) {
-            view->renderer()->config()->reloadSchema();
+            view->rendererConfig()->reloadSchema();
         }
     }
 
