@@ -12,7 +12,6 @@
 */
 
 #include "kateglobal.h"
-#include "config.h"
 
 #include <ktexteditor_version.h>
 
@@ -51,6 +50,7 @@
 #include <QScrollArea>
 #include <QScrollBar>
 #include <QStringListModel>
+#include <QTextToSpeech>
 #include <QTimer>
 
 // BEGIN unit test mode
@@ -204,11 +204,13 @@ KTextEditor::EditorPrivate::EditorPrivate(QPointer<KTextEditor::EditorPrivate> &
     //
     // init the cmds
     //
-    m_cmds.push_back(KateCommands::CoreCommands::self());
-    m_cmds.push_back(KateCommands::Character::self());
-    m_cmds.push_back(KateCommands::Date::self());
-    m_cmds.push_back(KateCommands::SedReplace::self());
-    m_cmds.push_back(KateCommands::Highlighting::self());
+    m_cmds = {
+        KateCommands::CoreCommands::self(),
+        KateCommands::Character::self(),
+        KateCommands::Date::self(),
+        KateCommands::SedReplace::self(),
+        KateCommands::Highlighting::self(),
+    };
 
     // global word completion model
     m_wordCompletionModel = new KateWordCompletionModel(this);
@@ -264,7 +266,7 @@ KTextEditor::Document *KTextEditor::EditorPrivate::createDocument(QObject *paren
 class KTextEditorConfigDialog : public KPageDialog
 {
 public:
-    QList<KTextEditor::ConfigPage *> editorPages;
+    std::vector<KTextEditor::ConfigPage *> editorPages;
 
     KTextEditorConfigDialog(KTextEditor::EditorPrivate *editor, QWidget *parent)
         : KPageDialog(parent)
@@ -282,7 +284,7 @@ public:
             item->setIcon(page->icon());
 
             connect(button(QDialogButtonBox::Apply), &QPushButton::clicked, page, &KTextEditor::ConfigPage::apply);
-            editorPages.append(page);
+            editorPages.push_back(page);
         }
     }
 
@@ -341,8 +343,8 @@ void KTextEditor::EditorPrivate::configDialog(QWidget *parent)
         KateViewConfig::global()->configStart();
         KateRendererConfig::global()->configStart();
 
-        for (int i = 0; i < kd->editorPages.count(); ++i) {
-            kd->editorPages.at(i)->apply();
+        for (auto *page : kd->editorPages) {
+            page->apply();
         }
 
         KateGlobalConfig::global()->configEnd();
@@ -417,25 +419,27 @@ KTextEditor::EditorPrivate *KTextEditor::EditorPrivate::self()
 void KTextEditor::EditorPrivate::registerDocument(KTextEditor::DocumentPrivate *doc)
 {
     Q_ASSERT(!m_documents.contains(doc));
-    m_documents.insert(doc, doc);
+    m_documents.push_back(doc);
 }
 
 void KTextEditor::EditorPrivate::deregisterDocument(KTextEditor::DocumentPrivate *doc)
 {
-    Q_ASSERT(m_documents.contains(doc));
-    m_documents.remove(doc);
+    int i = m_documents.indexOf(doc);
+    Q_ASSERT(i != -1);
+    m_documents.removeAt(i);
 }
 
 void KTextEditor::EditorPrivate::registerView(KTextEditor::ViewPrivate *view)
 {
-    Q_ASSERT(!m_views.contains(view));
-    m_views.insert(view);
+    Q_ASSERT(std::find(m_views.begin(), m_views.end(), view) == m_views.end());
+    m_views.push_back(view);
 }
 
 void KTextEditor::EditorPrivate::deregisterView(KTextEditor::ViewPrivate *view)
 {
-    Q_ASSERT(m_views.contains(view));
-    m_views.remove(view);
+    auto it = std::find(m_views.begin(), m_views.end(), view);
+    Q_ASSERT(it != m_views.end());
+    m_views.erase(it);
 }
 
 KTextEditor::Command *KTextEditor::EditorPrivate::queryCommand(const QString &cmd) const
@@ -504,7 +508,7 @@ bool KTextEditor::EditorPrivate::eventFilter(QObject *obj, QEvent *event)
 QStringListModel *KTextEditor::EditorPrivate::searchHistoryModel()
 {
     if (!m_searchHistoryModel) {
-        KConfigGroup cg(KSharedConfig::openConfig(), "KTextEditor::Search");
+        KConfigGroup cg(KSharedConfig::openConfig(), QStringLiteral("KTextEditor::Search"));
         const QStringList history = cg.readEntry(QStringLiteral("Search History"), QStringList());
         m_searchHistoryModel = new QStringListModel(history, this);
     }
@@ -514,7 +518,7 @@ QStringListModel *KTextEditor::EditorPrivate::searchHistoryModel()
 QStringListModel *KTextEditor::EditorPrivate::replaceHistoryModel()
 {
     if (!m_replaceHistoryModel) {
-        KConfigGroup cg(KSharedConfig::openConfig(), "KTextEditor::Search");
+        KConfigGroup cg(KSharedConfig::openConfig(), QStringLiteral("KTextEditor::Search"));
         const QStringList history = cg.readEntry(QStringLiteral("Replace History"), QStringList());
         m_replaceHistoryModel = new QStringListModel(history, this);
     }
@@ -523,7 +527,7 @@ QStringListModel *KTextEditor::EditorPrivate::replaceHistoryModel()
 
 void KTextEditor::EditorPrivate::saveSearchReplaceHistoryModels()
 {
-    KConfigGroup cg(KSharedConfig::openConfig(), "KTextEditor::Search");
+    KConfigGroup cg(KSharedConfig::openConfig(), QStringLiteral("KTextEditor::Search"));
     if (m_searchHistoryModel) {
         cg.writeEntry(QStringLiteral("Search History"), m_searchHistoryModel->stringList());
     }
@@ -584,4 +588,50 @@ QStringList KTextEditor::EditorPrivate::multicursorClipboard() const
     return m_multicursorClipboard;
 }
 
+QTextToSpeech *KTextEditor::EditorPrivate::speechEngine(KTextEditor::ViewPrivate *view)
+{
+    Q_ASSERT(view);
+    if (!m_speechEngine) {
+        m_speechEngine = new QTextToSpeech(this);
+
+        // error handler for errors happening during speech output
+        connect(m_speechEngine, &QTextToSpeech::errorOccurred, this, [this](QTextToSpeech::ErrorReason, const QString &errorString) {
+            if (m_speechEngineLastUser) {
+                speechError(m_speechEngineLastUser, errorString);
+            }
+        });
+
+        // handle init errors, that will not emit errorOccurred later
+        if (m_speechEngine->errorReason() != QTextToSpeech::ErrorReason::NoError) {
+            speechError(view, m_speechEngine->errorString());
+        }
+    }
+
+    // register current view, handle error output and stopping of the speaking
+    if (view != m_speechEngineLastUser) {
+        if (m_speechEngineLastUser) {
+            disconnect(m_speechEngineLastUser, &QObject::destroyed, this, &KTextEditor::EditorPrivate::speechEngineUserDestoyed);
+        }
+        m_speechEngineLastUser = view;
+        connect(m_speechEngineLastUser, &QObject::destroyed, this, &KTextEditor::EditorPrivate::speechEngineUserDestoyed);
+    }
+
+    return m_speechEngine;
+}
+
+void KTextEditor::EditorPrivate::speechEngineUserDestoyed()
+{
+    Q_ASSERT(m_speechEngine);
+    m_speechEngine->stop();
+}
+
+void KTextEditor::EditorPrivate::speechError(KTextEditor::ViewPrivate *view, const QString &errorString)
+{
+    Q_ASSERT(view);
+    auto message = new KTextEditor::Message(errorString, Message::Error);
+    message->setPosition(KTextEditor::Message::TopInView);
+    message->setView(view);
+    view->document()->postMessage(message);
+}
+
 #include "moc_kateglobal.cpp"
