@@ -12,14 +12,14 @@
 
 #include "range.h"
 
+#include <QByteArray>
+#include <QDebug>
+#include <QHash>
+#include <QString>
+
 using namespace KTextEditor;
 
-Range Range::fromString(const QStringRef &str) Q_DECL_NOEXCEPT
-{
-    return fromString(QStringView(str));
-}
-
-Range Range::fromString(QStringView str) Q_DECL_NOEXCEPT
+Range Range::fromString(QStringView str) noexcept
 {
     const int startIndex = str.indexOf(QLatin1Char('['));
     const int endIndex = str.indexOf(QLatin1Char(']'));
@@ -32,13 +32,13 @@ Range Range::fromString(QStringView str) Q_DECL_NOEXCEPT
     return Range(Cursor::fromString(str.mid(startIndex + 1, closeIndex - startIndex)), Cursor::fromString(str.mid(closeIndex + 2, endIndex - closeIndex - 2)));
 }
 
-void Range::setRange(const Range &range) Q_DECL_NOEXCEPT
+void Range::setRange(Range range) noexcept
 {
     m_start = range.start();
     m_end = range.end();
 }
 
-void Range::setRange(const Cursor &start, const Cursor &end) Q_DECL_NOEXCEPT
+void Range::setRange(Cursor start, Cursor end) noexcept
 {
     if (start > end) {
         setRange(Range(end, start));
@@ -47,7 +47,7 @@ void Range::setRange(const Cursor &start, const Cursor &end) Q_DECL_NOEXCEPT
     }
 }
 
-bool Range::confineToRange(const Range &range) Q_DECL_NOEXCEPT
+bool Range::confineToRange(Range range) noexcept
 {
     if (start() < range.start()) {
         if (end() > range.end()) {
@@ -64,7 +64,7 @@ bool Range::confineToRange(const Range &range) Q_DECL_NOEXCEPT
     return true;
 }
 
-bool Range::expandToRange(const Range &range) Q_DECL_NOEXCEPT
+bool Range::expandToRange(Range range) noexcept
 {
     if (start() > range.start()) {
         if (end() < range.end()) {
@@ -81,17 +81,17 @@ bool Range::expandToRange(const Range &range) Q_DECL_NOEXCEPT
     return true;
 }
 
-void Range::setBothLines(int line) Q_DECL_NOEXCEPT
+void Range::setBothLines(int line) noexcept
 {
     setRange(Range(line, start().column(), line, end().column()));
 }
 
-void KTextEditor::Range::setBothColumns(int column) Q_DECL_NOEXCEPT
+void KTextEditor::Range::setBothColumns(int column) noexcept
 {
     setRange(Range(start().line(), column, end().line(), column));
 }
 
-LineRange LineRange::fromString(QStringView str) Q_DECL_NOEXCEPT
+LineRange LineRange::fromString(QStringView str) noexcept
 {
     // parse format "[start, end]"
     const int startIndex = str.indexOf(QLatin1Char('['));
@@ -105,8 +105,8 @@ LineRange LineRange::fromString(QStringView str) Q_DECL_NOEXCEPT
     bool ok1 = false;
     bool ok2 = false;
 
-    const int start = str.mid(startIndex + 1, commaIndex - startIndex - 1).toString().toInt(&ok1); // FIXME KF6: Qt 5.15.2 and higher: remove .toString()
-    const int end = str.mid(commaIndex + 1, endIndex - commaIndex - 1).toString().toInt(&ok2); // FIXME KF6: Qt 5.15.2 and higher: remove .toString()
+    const int start = str.mid(startIndex + 1, commaIndex - startIndex - 1).toInt(&ok1);
+    const int end = str.mid(commaIndex + 1, endIndex - commaIndex - 1).toInt(&ok2);
 
     if (!ok1 || !ok2) {
         return invalid();
@@ -115,6 +115,38 @@ LineRange LineRange::fromString(QStringView str) Q_DECL_NOEXCEPT
     return {start, end};
 }
 
+QDebug operator<<(QDebug s, KTextEditor::Range range)
+{
+    s << "[" << range.start() << " -> " << range.end() << "]";
+    return s;
+}
+
+QDebug operator<<(QDebug s, KTextEditor::LineRange range)
+{
+    s << "[" << range.start() << " -> " << range.end() << "]";
+    return s;
+}
+
+size_t qHash(const KTextEditor::LineRange &range, size_t seed) noexcept
+{
+    return qHash(qMakePair(qHash(range.start()), qHash(range.end())), seed);
+}
+
+size_t qHash(const KTextEditor::Range &range, size_t seed) noexcept
+{
+    return qHash(qMakePair(qHash(range.start()), qHash(range.end())), seed);
+}
+
+QString Range::toString() const
+{
+    return QStringLiteral("[%1, %2]").arg(m_start.toString()).arg(m_end.toString());
+}
+
+QString LineRange::toString() const
+{
+    return QStringLiteral("[%1, %2]").arg(m_start).arg(m_end);
+}
+
 namespace QTest
 {
 // Cursor: template specialization for QTest::toString()
