@@ -18,18 +18,14 @@
 #include <QColor>
 #include <QHash>
 #include <QLayout>
-#include <QMap>
 #include <QPixmap>
 #include <QPointer>
 #include <QScrollBar>
-#include <QStackedWidget>
-#include <QTextLayout>
 #include <QTimer>
 
 #include "katetextline.h"
 #include <ktexteditor/cursor.h>
 #include <ktexteditor/message.h>
-#include <ktexteditor_export.h>
 
 namespace KTextEditor
 {
@@ -55,9 +51,9 @@ namespace Kate
 class TextRange;
 }
 
-class QTextCodec;
 class QTimer;
 class QVBoxLayout;
+class QStackedWidget;
 
 /**
  * Class to layout KTextEditor::Message%s in KateView. Only the floating
@@ -94,7 +90,7 @@ private:
         KTextEditor::Message::MessagePosition position = KTextEditor::Message::AboveView;
     };
 
-    QVector<ItemWrapper> m_items;
+    QList<ItemWrapper> m_items;
 };
 
 /**
@@ -193,14 +189,16 @@ private:
 
     int minimapYToStdY(int y);
 
-    using ColumnRangeWithColor = std::pair<QPen, std::pair<int, int>>;
-    ColumnRangeWithColor charColor(const QVector<Kate::TextLineData::Attribute> &attributes,
-                                   int &attributeIndex,
-                                   const QVector<Kate::TextRange *> &decorations,
-                                   const QBrush &defaultColor,
-                                   int x,
-                                   QChar ch,
-                                   QHash<QRgb, QPen> &penCache);
+    struct ColumnRangeWithColor {
+        int penIndex = -1;
+        int startColumn;
+        int endColumn;
+    };
+    void getCharColorRanges(const std::vector<Kate::TextLineData::Attribute> &attributes,
+                            const QList<Kate::TextRange *> &decorations,
+                            const QString &text,
+                            QList<KateScrollBar::ColumnRangeWithColor> &ranges,
+                            QVarLengthArray<std::pair<QRgb, QPen>, 20> &penCache);
 
     bool m_middleMouseDown;
     bool m_leftMouseDown;
@@ -223,12 +221,12 @@ private:
     int m_grooveHeight;
     QRect m_stdGroveRect;
     QRect m_mapGroveRect;
+    QRect m_sliderRect;
     QTimer m_updateTimer;
     QPoint m_toolTipPos;
 
     // lists of lines added/removed recently to avoid scrollbar flickering
     QHash<int, int> m_linesAdded;
-    int m_linesModified;
 
     static const unsigned char characterOpacity[256];
 };
@@ -330,6 +328,8 @@ private:
     void leaveEvent(QEvent *event) override;
     void wheelEvent(QWheelEvent *e) override;
 
+    void enterEvent(QEnterEvent *e) override;
+
     void showMarkMenu(uint line, const QPoint &pos);
 
     void hideAnnotationTooltip();
@@ -358,6 +358,7 @@ private:
     bool m_dynWrapIndicatorsOn : 1;
     bool m_annotationBorderOn : 1;
     bool m_updatePositionToArea : 1;
+    bool m_mouseOver = false;
 
     typedef QPair<int, KateIconBorder::BorderArea> AreaPosition;
     std::vector<AreaPosition> m_positionToArea;
@@ -395,59 +396,21 @@ private:
 
 class KateViewEncodingAction : public KSelectAction
 {
-    Q_OBJECT
-
-    Q_PROPERTY(QString codecName READ currentCodecName WRITE setCurrentCodec)
-    Q_PROPERTY(int codecMib READ currentCodecMib)
-
 public:
     KateViewEncodingAction(KTextEditor::DocumentPrivate *_doc, KTextEditor::ViewPrivate *_view, const QString &text, QObject *parent, bool saveAsMode = false);
 
-    int mibForName(const QString &codecName, bool *ok = nullptr) const;
-    QTextCodec *codecForMib(int mib) const;
-
-    QTextCodec *currentCodec() const;
-    bool setCurrentCodec(QTextCodec *codec);
-
-    QString currentCodecName() const;
-    bool setCurrentCodec(const QString &codecName);
-
-    int currentCodecMib() const;
-    bool setCurrentCodec(int mib);
-
-Q_SIGNALS:
-    /**
-     * Specific (proper) codec was selected
-     */
-    void codecSelected(QTextCodec *codec);
+    bool setCurrentCodec(const QString &codec);
 
 private:
+    void init();
+    void subActionTriggered(QAction *);
+
     KTextEditor::DocumentPrivate *doc;
     KTextEditor::ViewPrivate *view;
-
-    class Private
-    {
-    public:
-        explicit Private(KateViewEncodingAction *parent)
-            : q(parent)
-            , currentSubAction(nullptr)
-        {
-        }
-
-        void init();
-
-        void _k_subActionTriggered(QAction *);
-
-        KateViewEncodingAction *q;
-        QAction *currentSubAction;
-    };
-
-    std::unique_ptr<Private> const d;
-    Q_PRIVATE_SLOT(d, void _k_subActionTriggered(QAction *))
-
+    QAction *currentSubAction;
     const bool m_saveAsMode;
 
-private Q_SLOTS:
+private:
     void setEncoding(const QString &e);
     void slotAboutToShow();
 };
@@ -587,10 +550,8 @@ private:
     QVBoxLayout *m_layout;
 };
 
-class KTEXTEDITOR_EXPORT KateCommandLineBar : public KateViewBarWidget
+class KateCommandLineBar : public KateViewBarWidget
 {
-    Q_OBJECT
-
 public:
     explicit KateCommandLineBar(KTextEditor::ViewPrivate *view, QWidget *parent = nullptr);
     ~KateCommandLineBar() override;
@@ -598,8 +559,8 @@ public:
     void setText(const QString &text, bool selected = true);
     void execute(const QString &text);
 
-public Q_SLOTS:
-    void showHelpPage();
+public:
+    static void showHelpPage();
 
 private:
     class KateCmdLineEdit *m_lineEdit;
@@ -654,25 +615,8 @@ private:
     QTimer *m_hideTimer;
 };
 
-class KatePasteMenu : public KActionMenu
-{
-    Q_OBJECT
-
-public:
-    KatePasteMenu(const QString &text, KTextEditor::ViewPrivate *view);
-
-private:
-    KTextEditor::ViewPrivate *m_view;
-
-private Q_SLOTS:
-    void slotAboutToShow();
-    void paste();
-};
-
 class KateViewSchemaAction : public KActionMenu
 {
-    Q_OBJECT
-
 public:
     KateViewSchemaAction(const QString &text, QObject *parent)
         : KActionMenu(text, parent)
@@ -691,10 +635,10 @@ private:
     QActionGroup *m_group;
     int last;
 
-public Q_SLOTS:
+public:
     void slotAboutToShow();
 
-private Q_SLOTS:
+private:
     void setSchema();
 };
 
