@@ -11,9 +11,6 @@
 #include "katedocument.h"
 #include "kateglobal.h"
 #include "katelayoutcache.h"
-#include "katerenderer.h"
-#include "kateview.h"
-#include "kateviewinternal.h"
 #include "kateviinputmode.h"
 #include "ktexteditor/message.h"
 #include <vimode/globalstate.h>
